==> paperwork-1.2.4.tar.gz: paperwork-1.2.4/src/paperwork/_version.py <==
# -*- coding: utf-8 -*-
version = "1.2.4"
authors_code = """
    Code contributors:
  1855	Jerome Flesch <jflesch@gmail.com>
   830	Jerome Flesch <jflesch@openpaper.work>
   164	Jerome Flesch <jflesch@wyplay.com>
   160	jflesch <jflesch@gmail.com>
    50	Jerome Flesch <jerome.flesch@netasq.com>
    42	Mathieu Jourdan <mathieu.jourdan@gresille.org>
    35	Josselin Jacquard <josselin.jacquard@gmail.com>
    11	Tristan Kohl <blobbyjj@ymail.com>
    10	Jerome Flesch <jflesch@kwain.net>
     7	François Schmidts <francois.schmidts@gmail.com>
     7	RyDroid <rydroid_dev@yahoo.com>
     5	Matthieu Coudron <mattator@gmail.com>
     5	Paul Liétar <paul@lietar.net>
     4	Sébastien Maccagnoni-Munch <sebastien@smm-informatique.fr>
     3	Alexandre Vaissière <avaiss@fmiw.org>
     3	mirodin <blobbyjj@ymail.com>
     2	Christophe Delaere <christophe.delaere@cern.ch>
     2	Davidbrcz <Davidbrcz@users.noreply.github.com>
     2	Markus Mayr <markusmayr@gmx.net>
     2	Mathieu Schopfer <mathieu.schopfer@protonmail.ch>
     2	Matthias Mailänder <Mailaender@users.noreply.github.com>
     2	Patrick Scheid <p.scheid92@gmail.com>
     2	Sebastian Spaeth <Sebastian@SSpaeth.de>
     2	Sébastien Maccagnoni <sebastien@maccagnoni.eu>
     2	Thomas Clavier <tom@tcweb.org>
     2	lb1a <github@lb1a.de>
     2	pingtux <pingtux@users.noreply.github.com>
     1	Alain <github@STudio26.no-ip.biz>
     1	Bignaux Ronan <ronan@aimao.org>
     1	Christophe 'RTDaemons' GERARDIN <cgerardin@elitemail.org>
     1	Christophe Chauvet <christophe.chauvet@gmail.com>
     1	Daniel Hahler <git@thequod.de>
     1	Daniel Korostil <ted.korostiled@gmail.com>
     1	Dominique Hazael-Massieux <dom@w3.org>
     1	Gautier Pelloux-Prayer <bagage@users.noreply.github.com>
     1	Glandos <bugs-github@antipoul.fr>
     1	Hannes <textPreferred@users.noreply.github.com>
     1	Jehan <jehan@girinstud.io>
     1	Krap <Krap@users.noreply.github.com>
     1	Notkea <pacien@users.noreply.github.com>
     1	Paul Liétar <paul@lietar.net>
     1	Samuel Dorsaz <ajira86@hotmail.com>
     1	Santiago Castro <bryant@montevideo.com.uy>
     1	Stefan Pokorny <stefan@stefanpokorny.de>
     1	arthurlutz <arthur.lutz@gmail.com>
     1	claudex <claude.xavier@gmail.com>
     1	foudfou <foudil.newbie+git@gmail.com>
     1	ludo <ludo@zyrianes.net>
     1	swap38 <swap38@no-log.org>
"""

# Code contributors is automatically completed by the Makefile

authors_ui = """
	Mathieu Jourdan <mathieu.jourdan@gresille.org>
	"""

authors_translators = """
	French: Jerome Flesch <jflesch@openpaper.work>
	German: Tristan Kohl (Mirodin) <blobbyjj@ymail.com>
	Ukrainian: Daniel Korostil <ted.korostiled@gmail.com>
    """

authors_documentation = """
	Alain <github@STudio26.no-ip.biz>
	arthurlutz <arthur.lutz@gmail.com>
	Christophe Delaere <christophe.delaere@cern.ch>
	Christophe GERARDIN (RTDaemons) <cgerardin@elitemail.org>
	Daniel Hahler <git@thequod.de>
	Davidbrcz <Davidbrcz@users.noreply.github.com>
	Jehan <jehan@girinstud.io>
	lb1a <github@lb1a.de>
	Ludo <ludo@zyrianes.net>
	Samuel Dorsaz <ajira86@hotmail.com>
	Santiago Castro <bryant@montevideo.com.uy>
	swap38 <swap38@no-log.org>
    """

==> paperwork-1.3.0.tar.gz: paperwork-1.3.0/src/paperwork/_version.py <==
# -*- coding: utf-8 -*-
version = "1.3.0-1-g5a1f2fb3"
authors_code = """
    Code contributors:
  1855	Jerome Flesch <jflesch@gmail.com>
  1138	Jerome Flesch <jflesch@openpaper.work>
   164	Jerome Flesch <jflesch@wyplay.com>
   160	jflesch <jflesch@gmail.com>
    50	Jerome Flesch <jerome.flesch@netasq.com>
    46	Mathieu Jourdan <mathieu.jourdan@gresille.org>
    35	Josselin Jacquard <josselin.jacquard@gmail.com>
    31	Jerome Flesch <jflesch@kwain.net>
    23	Elliott Sales de Andrade <quantum.analyst@gmail.com>
    15	Jerome Flesch <jflech@openpaper.work>
    11	Tristan Kohl <blobbyjj@ymail.com>
     8	toerb <toerbnator@jedirat.org>
     7	François Schmidts <francois.schmidts@gmail.com>
     7	Jérémy BUCHOU <jeremy.buchou@gmail.com>
     7	RyDroid <rydroid_dev@yahoo.com>
     6	Balló György <ballogyor@gmail.com>
     6	Joshua Kramer <joskra42@gmail.com>
     5	Matthieu Coudron <mattator@gmail.com>
     5	Paul Liétar <paul@lietar.net>
     4	Sébastien Maccagnoni-Munch <sebastien@smm-informatique.fr>
     3	Alexandre Vaissière <avaiss@fmiw.org>
     3	Stéphane Brunner <stephane.brunner@camptocamp.com>
     3	mirodin <blobbyjj@ymail.com>
     2	Christophe Delaere <christophe.delaere@cern.ch>
     2	Davidbrcz <Davidbrcz@users.noreply.github.com>
     2	Jonas Wloka <code@jowlo.de>
     2	Markus Mayr <markusmayr@gmx.net>
     2	Mathieu Schopfer <mathieu.schopfer@protonmail.ch>
     2	Matthias Mailänder <Mailaender@users.noreply.github.com>
     2	Patrick Scheid <p.scheid92@gmail.com>
     2	Sebastian Spaeth <Sebastian@SSpaeth.de>
     2	Sébastien Maccagnoni <sebastien@maccagnoni.eu>
     2	Thomas Clavier <tom@tcweb.org>
     2	lb1a <github@lb1a.de>
     2	pingtux <pingtux@users.noreply.github.com>
     1	Alain <github@STudio26.no-ip.biz>
     1	Bastien Nocera <hadess@hadess.net>
     1	Bignaux Ronan <ronan@aimao.org>
     1	Christophe 'RTDaemons' GERARDIN <cgerardin@elitemail.org>
     1	Christophe Chauvet <christophe.chauvet@gmail.com>
     1	Daniel Hahler <git@thequod.de>
     1	Daniel Korostil <ted.korostiled@gmail.com>
     1	Dominique Hazael-Massieux <dom@w3.org>
     1	François Boulogne <fboulogne@sciunto.org>
     1	Gautier Pelloux-Prayer <bagage@users.noreply.github.com>
     1	Glandos <bugs-github@antipoul.fr>
     1	Hannes <textPreferred@users.noreply.github.com>
     1	Jehan <jehan@girinstud.io>
     1	Johnny Stenback <github@jstenback.com>
     1	Justin P <Jpartain89@gmail.com>
     1	Krap <Krap@users.noreply.github.com>
     1	Notkea <pacien@users.noreply.github.com>
     1	Paul Liétar <paul@lietar.net>
     1	Samuel Dorsaz <ajira86@hotmail.com>
     1	Santiago Castro <bryant@montevideo.com.uy>
     1	Stefan Pokorny <stefan@stefanpokorny.de>
     1	arthurlutz <arthur.lutz@gmail.com>
     1	claudex <claude.xavier@gmail.com>
     1	foudfou <foudil.newbie+git@gmail.com>
     1	ludo <ludo@zyrianes.net>
     1	swap38 <swap38@no-log.org>
"""

# Code contributors is automatically completed by the Makefile

authors_ui = """
	Mathieu Jourdan <mathieu.jourdan@gresille.org>
	"""

authors_translators = """
	French: Jerome Flesch <jflesch@openpaper.work>
	German: Tristan Kohl (Mirodin) <blobbyjj@ymail.com>
	Ukrainian: Daniel Korostil <ted.korostiled@gmail.com>
    """

authors_documentation = """
	Alain <github@STudio26.no-ip.biz>
	arthurlutz <arthur.lutz@gmail.com>
	Christophe Delaere <christophe.delaere@cern.ch>
	Christophe GERARDIN (RTDaemons) <cgerardin@elitemail.org>
	Daniel Hahler <git@thequod.de>
	Davidbrcz <Davidbrcz@users.noreply.github.com>
	Jehan <jehan@girinstud.io>
	lb1a <github@lb1a.de>
	Ludo <ludo@zyrianes.net>
	Samuel Dorsaz <ajira86@hotmail.com>
	Santiago Castro <bryant@montevideo.com.uy>
	swap38 <swap38@no-log.org>
    """
